summaryrefslogtreecommitdiffstats
path: root/quanta/parsers/node.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
commite985f7e545f4739493965aad69bbecb136dc9346 (patch)
tree54afd409d8acd6202dd8ab611d24e78c28e4c0a0 /quanta/parsers/node.h
parentf7670c198945adc3b95ad69a959fe5f8ae55b493 (diff)
downloadtdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.tar.gz
tdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.zip
TQt4 port kdewebdev
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1237029 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'quanta/parsers/node.h')
-rw-r--r--quanta/parsers/node.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/quanta/parsers/node.h b/quanta/parsers/node.h
index 4e3451af..ab8e6267 100644
--- a/quanta/parsers/node.h
+++ b/quanta/parsers/node.h
@@ -36,8 +36,8 @@ struct GroupElement{
Node *node;
/* The tag which point to the actual place in the node */
Tag *tag;
- /*The parent node indicating the beginning of a structure */
- Node *parentNode;
+ /*The tqparent node indicating the beginning of a structure */
+ Node *tqparentNode;
bool global;
bool deleted;
TQString type;
@@ -48,7 +48,7 @@ typedef TQValueList<GroupElement*> GroupElementList;
typedef TQMap<TQString, GroupElementList> GroupElementMapList;
/**
* A Node is a basic unit of a Tree. It keeps track of his parent, his left neighbour, his right neighbour
* and his first child.
* It contains some functions to navigate through the tree, but some more are located at kafkacommon.h
* (and should be moved here...)
@@ -61,7 +61,7 @@ typedef TQMap<TQString, GroupElementList> GroupElementMapList;
class Node {
public:
- Node( Node *parent );
+ Node( Node *tqparent );
~Node();
/**
@@ -73,7 +73,7 @@ public:
static bool deleteNode(Node *node);
/**
* Copy everything from node except prev, next, child, parent, listItem, group, groupTag, which are set to Null
* The groupElementsList is cleared.
*/
void operator =(Node* node);
@@ -84,22 +84,22 @@ public:
Node *next;
Node *prev;
- Node *parent;
+ Node *tqparent;
Node *child;
/** Returns the child if available, else the next node, else the next node of the first parent which has one, else 0L.
WARNING: it doesn't behave like DOM::Node::nextSibling() which give the next Node, or 0L if there is no next Node */
Node *nextSibling();
Node *previousSibling();
- /** Returns the next node, or the parent's next, if next doesn't exists,
- or the granparent's next, if parent's next doesn't exists, etc. */
+ /** Returns the next node, or the tqparent's next, if next doesn't exists,
+ or the grantqparent's next, if tqparent's next doesn't exists, etc. */
Node *nextNotChild();
/** DOM like functions cf dom/dom_node.h */
TQString nodeName();
TQString nodeValue();
void setNodeValue(const TQString &value);
- Node* parentNode() {return parent;}
+ Node* tqparentNode() {return tqparent;}
Node* firstChild() {return child;}
Node* lastChild();
Node* DOMpreviousSibling() {return prev;}
@@ -113,7 +113,7 @@ public:
/** Others functions. */
// check if Node has node in its child subtree (and grand-child,...)
bool hasForChild(Node *node);
- void setParent(Node *nodeParent) {parent = nodeParent;}
+ void setParent(Node *nodeParent) {tqparent = nodeParent;}
//If Node is of type XmlTag or ScriptTag, return the corresponding XmlTagEnd if available
Node *getClosingNode();
//If Node is of type XmlTagEnd, return the corresponding XmlTag or ScriptTag if available
@@ -130,7 +130,7 @@ public:
Node *lastChildNE();
/**
* The main problem manipulating the default links prev/next/parent/child is that we often want
* to manipulate only the "significant" Nodes e.g. XmlTag, Text, ScriptNode, like in a DOM::Node tree.
* These functions, prefixed with "S" which stands for "simplified" or "significant", will only return
* and manipulate XmlTag, Text and ScriptNode.
@@ -48,7 +48,7 @@ typedef TQValueList<GroupElement*> GroupElementList;
typedef TQMap<TQString, GroupElementList> GroupElementMapList;
/**
- * A Node is a basic unit of a Tree. It keeps track of his parent, his left neighbour, his right neighbour
+ * A Node is a basic unit of a Tree. It keeps track of his tqparent, his left neighbour, his right neighbour
* and his first child.
* It contains some functions to navigate through the tree, but some more are located at kafkacommon.h
@@ -73,7 +73,7 @@ public:
static bool deleteNode(Node *node);
/**
- * Copy everything from node except prev, next, child, parent, listItem, group, groupTag, which are set to Null
+ * Copy everything from node except prev, next, child, tqparent, listItem, group, groupTag, which are set to Null
* The groupElementsList is cleared.
*/
@@ -84,22 +84,22 @@ public:
Node *child;
- /** Returns the child if available, else the next node, else the next node of the first parent which has one, else 0L.
+ /** Returns the child if available, else the next node, else the next node of the first tqparent which has one, else 0L.
WARNING: it doesn't behave like DOM::Node::nextSibling() which give the next Node, or 0L if there is no next Node */
Node *nextSibling();
@@ -130,7 +130,7 @@ public:
Node *lastChildNE();
/**
- * The main problem manipulating the default links prev/next/parent/child is that we often want
+ * The main problem manipulating the default links prev/next/tqparent/child is that we often want
* to manipulate only the "significant" Nodes e.g. XmlTag, Text, ScriptNode, like in a DOM::Node tree.
* These functions, prefixed with "S" which stands for "simplified" or "significant", will only return